@@ -1,15 +1,35 @@
-""" Entry point for tsrc log """
+""" Entry point for `tsrc log`. """
 
 import argparse
 
 import cli_ui as ui
 
 import tsrc
-import tsrc.cli
+from tsrc.cli import (
+    add_repos_selection_args,
+    add_workspace_arg,
+    get_workspace_with_repos,
+)
 
 
-def main(args: argparse.Namespace) -> None:
-    workspace = tsrc.cli.get_workspace_with_repos(args)
+def configure_parser(subparser: argparse._SubParsersAction) -> None:
+    parser = subparser.add_parser("log")
+    add_workspace_arg(parser)
+    add_repos_selection_args(parser)
+    parser.add_argument(
+        "--from", dest="from_ref", metavar="FROM", help="run `git log` from this ref"
+    )
+    parser.add_argument(
+        "--to",
+        dest="to_ref",
+        default="HEAD",
+        help="run `git log` until this ref",
+    )
+    parser.set_defaults(run=run)
+
+
+def run(args: argparse.Namespace) -> None:
+    workspace = get_workspace_with_repos(args)
     all_ok = True
     for repo in workspace.repos:
         full_path = workspace.root_path / repo.dest
@@ -25,7 +45,7 @@ def main(args: argparse.Namespace) -> None:
             "log",
             "--color=always",
             f"--pretty=format:{log_format}",
-            f"{args.from_}...{args.to}",
+            f"{args.from_ref}...{args.to_ref}",
         ]
         rc, out = tsrc.git.run_captured(full_path, *cmd, check=False)
         if rc != 0:
