@@ -1,15 +1,13 @@
 """ Custom exceptions """
 
+from pathlib import Path
 from typing import Any
-from path import Path
 
-DOC_URL = "https://TankerHQ.github.io/tsrc/ref/formats/"
+DOC_URL = "https://dmerejkowsky.github.io/tsrc/ref/formats/"
 
 
 class Error(Exception):
-    """ Base class for our own errors
-
-    """
+    """Base class for our own errors."""
 
     def __init__(self, *args: Any) -> None:
         super().__init__(self, *args)
