@@ -1,14 +1,16 @@
-from tsrc.test.helpers.cli import CLI
-from tsrc.test.helpers.git_server import GitServer
+import shutil
+from pathlib import Path
+
 import ruamel.yaml
 
-from path import Path
+from tsrc.test.helpers.cli import CLI
+from tsrc.test.helpers.git_server import GitServer
 
 
 def test_apply_manifest_adds_new_repo(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
+    """Scenario:
 
     * Create a manifest with one repo
     * Create a workspace using `tsrc init`
@@ -23,12 +25,13 @@ def test_apply_manifest_adds_new_repo(
     tsrc_cli.run("init", git_server.manifest_url)
 
     cloned_manifest_path = workspace_path / ".tsrc/manifest/manifest.yml"
-    copied_manifest_path = Path(cloned_manifest_path.copy(workspace_path))
+    copied_manifest_path = workspace_path / "manifest.yml"
+    shutil.copy(cloned_manifest_path, copied_manifest_path)
 
     bar_url = git_server.add_repo("bar", add_to_manifest=False)
     add_repo_to_manifest(copied_manifest_path, "bar", bar_url)
 
-    tsrc_cli.run("apply-manifest", copied_manifest_path)
+    tsrc_cli.run("apply-manifest", str(copied_manifest_path))
 
     assert (workspace_path / "bar").exists(), "bar repo should have been cloned"
 
