@@ -1,9 +1,9 @@
-from path import Path
+from pathlib import Path
+
+from cli_ui.tests import MessageRecorder
 
 import tsrc
 import tsrc.git
-
-from cli_ui.tests import MessageRecorder
 from tsrc.test.helpers.cli import CLI
 from tsrc.test.helpers.git_server import GitServer
 
