@@ -1,19 +1,19 @@
-from typing import Any
 import os
+from pathlib import Path
+from typing import Any
 
-from path import Path
+import ruamel.yaml
+from cli_ui.tests import MessageRecorder
 
 import tsrc.cli
-from tsrc.workspace.config import WorkspaceConfig
 from tsrc.groups import GroupNotFound
-
-from cli_ui.tests import MessageRecorder
 from tsrc.test.helpers.cli import CLI
 from tsrc.test.helpers.git_server import GitServer
+from tsrc.workspace.config import WorkspaceConfig
 
 
 def test_sync_happy(tsrc_cli: CLI, git_server: GitServer, workspace_path: Path) -> None:
-    """" Scenario:
+    """ " Scenario:
     * Create a manifest with two repos (foo and bar)
     * Initialize a workspace from this manifest
     * Push a new file to the foo repo
@@ -38,7 +38,7 @@ def test_sync_with_errors(
     workspace_path: Path,
     message_recorder: MessageRecorder,
 ) -> None:
-    """" Scenario:
+    """ " Scenario:
     * Create a manifest with two repos (foo and bar)
     * Initialize a workspace from this manifest
     * Push a new file to the foo repo
@@ -65,7 +65,7 @@ def test_sync_with_errors(
 def test_sync_finds_root(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path, monkeypatch: Any
 ) -> None:
-    """ Check that you can run `tsrc sync` from inside a cloned
+    """Check that you can run `tsrc sync` from inside a cloned
     repository
 
     """
@@ -106,8 +106,8 @@ def change_workspace_manifest_branch(workspace_path: Path, branch: str) -> None:
 def test_switching_manifest_branch(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
-    * Initialize aw workspace with a manifest on the master branch
+    """Scenario:
+    * Initialize a new workspace with a manifest on the master branch
     * Create a new repo bar, on the 'devel' branch of the manifest
     * Run `tsrc sync`: bar should not get cloned
     * Configure the workspace to use the `devel` branch of the manifest
@@ -137,15 +137,15 @@ def test_sync_not_on_master(
     workspace_path: Path,
     message_recorder: MessageRecorder,
 ) -> None:
-    """"
-   Scenario:
-   * Create a manifest with two repos, foo and bar
-   * Initialize a workspace from this manifest
-   * Checkout a different branch on foo, tracking an existing remote
-   * Run `tsrc sync`
-   * Check that:
-      * foo is updated
-      * but the command fails because foo was not an the expected branch
+    """ "
+    Scenario:
+    * Create a manifest with two repos, foo and bar
+    * Initialize a workspace from this manifest
+    * Checkout a different branch on foo, tracking an existing remote
+    * Run `tsrc sync`
+    * Check that:
+       * foo is updated
+       * but the command fails because foo was not an the expected branch
     """
     git_server.add_repo("foo")
     git_server.add_repo("bar")
@@ -192,6 +192,73 @@ def test_sync_with_force(
     ).read_text() == "2", "foo should have been reset to the latest tag"
 
 
+def add_repo_unstaged(name: str, git_server: GitServer, workspace_path: Path) -> None:
+    """Add a repo to the manifest without staging this change."""
+    repo_config = {"url": git_server.get_url(name), "dest": name}
+    manifest_data = git_server.manifest.data.copy()
+    manifest_data["repos"].append(repo_config)
+    manifest_path = workspace_path / ".tsrc" / "manifest" / "manifest.yml"
+    with open(manifest_path, "w") as manifest:
+        to_write = ruamel.yaml.dump(manifest_data)
+        assert to_write
+        manifest.write(to_write)
+
+
+def test_sync_discards_local_manifest_changes(
+    tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
+) -> None:
+    """
+    Scenario:
+    * Create a manifest with one repo, foo
+    * Initialize a workspace from this manifest
+    * Add repo bar and do not commit or push this change
+    * Run tsrc sync
+    * The manifest is updated from the remote, and the change is discarded
+    * Only foo is present after the sync
+    """
+    git_server.add_repo("foo")
+    git_server.push_file("foo", "foo.txt", contents="foo")
+    tsrc_cli.run("init", git_server.manifest_url)
+
+    git_server.add_repo("bar", add_to_manifest=False)
+    git_server.push_file("bar", "bar.txt", contents="bar")
+    add_repo_unstaged("bar", git_server, workspace_path)
+
+    tsrc_cli.run("sync")
+
+    bar_path = workspace_path / "bar"
+    assert not bar_path.exists(), "bar should not have been synced"
+
+
+def test_sync_with_no_update_manifest_flag_leaves_changes(
+    tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
+) -> None:
+    """
+    Scenario:
+    * Create a manifest with one repo, foo
+    * Initialize a workspace from this manifest
+    * Add repo bar and do not commit or push this change
+    * Run tsrc sync --no-update-manifest
+    * The manifest is not updated from the remote, and the change is left
+    * Both foo and bar are present after the sync
+    """
+    git_server.add_repo("foo")
+    git_server.push_file("foo", "foo.txt", contents="foo")
+    tsrc_cli.run("init", git_server.manifest_url)
+
+    git_server.add_repo("bar", add_to_manifest=False)
+    git_server.push_file("bar", "bar.txt", contents="bar")
+    add_repo_unstaged("bar", git_server, workspace_path)
+
+    tsrc_cli.run("sync", "--no-update-manifest")
+
+    bar_path = workspace_path / "bar"
+    assert bar_path.exists(), "bar should have been synced"
+    assert (
+        bar_path / "bar.txt"
+    ).read_text() == "bar", "bar should have the correct contents"
+
+
 def test_copies_are_up_to_date(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
@@ -244,7 +311,7 @@ def test_copies_preserve_stat(
 def test_update_symlink(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
+    """Scenario:
     * Crate a manifest with a 'foo' repo
     * Push 'foo.txt' to the 'foo' repo
     * Configure the 'foo' repo with a symlink copy from 'foo.link' to 'foo/foo.txt'
@@ -267,7 +334,7 @@ def test_update_symlink(
 
     actual_link = workspace_path / "foo.link"
     assert actual_link.exists()
-    assert actual_link.readlink() == os.path.normpath("foo/bar.txt")
+    assert os.readlink(str(actual_link)) == os.path.normpath("foo/bar.txt")
 
 
 def test_changing_branch(
@@ -276,7 +343,7 @@ def test_changing_branch(
     workspace_path: Path,
     message_recorder: MessageRecorder,
 ) -> None:
-    """ Scenario:
+    """Scenario:
     * Create a manifest with a foo repo
     * Initialize a workspace from this manifest
     * Create a new branch named `next` on the foo repo
@@ -299,7 +366,7 @@ def test_changing_branch(
 def test_tags_are_not_updated(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
+    """Scenario:
     * Create a manifest with a foo repo, frozen at the `v0.1` tag
     * Initialize a workspace from this manifest
     * Push a new file to the foo repo
@@ -325,7 +392,7 @@ def test_tags_are_not_updated(
 def test_sha1s_are_not_updated(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
+    """Scenario:
     * Create a manifest with a foo repo, frozen at a given revision
     * Initialize a workspace from this manifest
     * Push a new file to the foo repo
@@ -351,7 +418,7 @@ def test_sha1s_are_not_updated(
 def test_tags_are_updated_when_clean(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
+    """Scenario:
     * Create a manifest with a foo repo, frozen at the v0.1 tag
     * Initialize a workspace from this manifest
     * Push a new file to the foo repo
@@ -381,7 +448,7 @@ def test_tags_are_updated_when_clean(
 def test_sha1s_are_updated_when_clean(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
+    """Scenario:
     * Create a manifest with a foo repo, frozen at an initial revision
     * Initialize a workspace from this manifest
     * Push a new file to the foo repo
@@ -410,7 +477,7 @@ def test_sha1s_are_updated_when_clean(
 def test_tags_are_skipped_when_not_clean_tags(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
+    """Scenario:
     * Create a manifest with a foo repo, frozen at the v0.1 tag
     * Initialize a workspace from this manifest
     * Push a new file to the foo repo
@@ -441,7 +508,7 @@ def test_tags_are_skipped_when_not_clean_tags(
 def test_sha1s_are_skipped_when_not_clean(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
+    """Scenario:
     * Create a manifest with a foo repo, frozen at an initial revision
     * Initialize a workspace from this manifest
     * Push a new file to the foo repo
@@ -472,7 +539,7 @@ def test_sha1s_are_skipped_when_not_clean(
 def test_sync_uses_group_from_config_by_default(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
+    """Scenario:
     * Create a manifest containing:
       * a group named 'foo'  containing the repos 'bar'  and 'baz'
       * a repo named 'other' not in any group
@@ -501,7 +568,7 @@ def test_sync_uses_group_from_config_by_default(
 def test_fetch_additional_remotes(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
+    """Scenario:
     * Create a manifest containing a foo repo with two remotes
     * Initialize a workspace from this manifest
     * Update the second remote
@@ -526,7 +593,7 @@ def test_fetch_additional_remotes(
 def test_adding_remotes(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
+    """Scenario:
     * Create a manifest containing a foo repo with one remote
     * Initialize a workspace from this manifest
     * Add an 'other' remote to the foo repo in the manifest
@@ -549,7 +616,7 @@ def test_adding_remotes(
 def test_changing_remote_url(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
+    """Scenario:
     * Create a manifest containing a foo repo with one remote
     * Initialize a workspace from this manifest
     * Change the url in the manifest
@@ -571,13 +638,13 @@ def test_changing_remote_url(
 def test_sync_with_singular_remote(
     tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
 ) -> None:
-    """ Scenario:
-     * Create a manifest that contains one repo with two remotes
-       ('origin' and 'vpn')
-     * Marke sure that the 'origin' URL is valid but the 'vpn'
-       URL is not.
-     * Run 'tsrc init -r origin'
-     * Check that 'tsrc sync' does not try and fetch the 'vpn' remote
+    """Scenario:
+    * Create a manifest that contains one repo with two remotes
+      ('origin' and 'vpn')
+    * Make sure that the 'origin' URL is valid but the 'vpn'
+      URL is not.
+    * Run 'tsrc init -r origin'
+    * Check that 'tsrc sync' does not try and fetch the 'vpn' remote
     """
     foo_url = git_server.add_repo("foo")
     vpn_url = "/does/not/exist"
@@ -597,7 +664,7 @@ class TestSyncWithGroups:
     def test_ignore_other_groups(
         tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
     ) -> None:
-        """ Scenario:
+        """Scenario:
         * Create a manifest containing:
           * a group named 'group1' containing the repos 'foo'  and 'bar'
           * a group named 'group2' containing the repo 'baz'
@@ -644,16 +711,16 @@ class TestSyncWithGroups:
     def test_honors_new_included_groups(
         tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
     ) -> None:
-        """ Scenario:
-       * Create a manifest containing:
-         * a group named 'group1'  containing the repos 'foo'  and 'bar'
-         * a group named 'group2' containing the repo 'baz'
-       * Initialize a workspace from this manifest using the 'group1' and 'group2' groups
-       * Create a new group 'inc' containing the repo 'quux'
-       * Update 'group1' group to include 'inc'
-       * Run `tsrc sync --group 'group1'
-       * Check that `quux` is cloned
-       """
+        """Scenario:
+        * Create a manifest containing:
+          * a group named 'group1'  containing the repos 'foo'  and 'bar'
+          * a group named 'group2' containing the repo 'baz'
+        * Initialize a workspace from this manifest using the 'group1' and 'group2' groups
+        * Create a new group 'inc' containing the repo 'quux'
+        * Update 'group1' group to include 'inc'
+        * Run `tsrc sync --group 'group1'
+        * Check that `quux` is cloned
+        """
         git_server.add_group("group1", ["foo", "bar"])
         git_server.add_group("group2", ["baz"])
         tsrc_cli.run("init", git_server.manifest_url, "--groups", "group1", "group2")
@@ -669,7 +736,7 @@ class TestSyncWithGroups:
     def test_can_use_new_group(
         tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
     ) -> None:
-        """ Scenario:
+        """Scenario:
         * Create a manifest containing:
           * a group named 'default'  containing the repos 'foo'  and 'bar'
         * Initialize a workspace from this manifest using the default group
@@ -702,8 +769,8 @@ class TestSyncWithGroups:
     def test_non_existing_group(
         tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
     ) -> None:
-        """ Scenario:
-        * Create a manifest contaning :
+        """Scenario:
+        * Create a manifest containing :
           * a group named 'group1'  containing the repo 'foo'
           * a group named 'group2'  containing the repo 'bar'
         * Initialize a workspace from this manifest using the 'group1' and 'group2' groups
@@ -720,8 +787,8 @@ class TestSyncWithGroups:
     def test_group_not_cloned(
         tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
     ) -> None:
-        """ Scenario:
-        * Create a manifest contaning :
+        """Scenario:
+        * Create a manifest containing :
           * a group named 'group1'  containing the repo 'foo'
           * a group named 'group2'  containing the repo 'bar'
         * Initialize a workspace from this manifest using the 'group1'
@@ -737,3 +804,41 @@ class TestSyncWithGroups:
         assert (
             workspace_path / "bar"
         ).exists(), "bar should have been cloned when syncing group2"
+
+
+def test_update_submodules(
+    tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
+) -> None:
+    """
+    Scenario:
+    * Create repo 'sub1' containing a 'sub2' submodule
+    * Create a repo 'top' containing the 'sub1' submodule
+    * Add 'top' to the manifest
+    * Run `tsrc init`
+    * Create commit in sub2
+    * Update sub2 submodule in sub1
+    * Update sub1 submodule in sub2
+
+    * Run `tsrc sync`
+
+    * Check that everything was updated
+    """
+
+    git_server.add_repo("top")
+    sub1_url = git_server.add_repo("sub1", add_to_manifest=False)
+    sub2_url = git_server.add_repo("sub2", add_to_manifest=False)
+    git_server.add_submodule("sub1", url=sub2_url, path=Path("sub2"))
+    git_server.add_submodule("top", url=sub1_url, path=Path("sub1"))
+
+    tsrc_cli.run("init", git_server.manifest_url, "-r", "origin")
+
+    git_server.push_file("sub2", "new.txt")
+    git_server.update_submodule("sub1", "sub2")
+    git_server.update_submodule("top", "sub1")
+
+    tsrc_cli.run("sync")
+
+    clone_path = workspace_path / "top"
+
+    sub2_new_txt = clone_path / "sub1" / "sub2" / "new.txt"
+    assert sub2_new_txt.exists(), "sub2 was not updated"
