@@ -1,24 +1,24 @@
-from typing import Any, Callable
+""" Helper to call tsrc's main() function.
+
+Used by the `tsrc_cli` fixture.
+"""
+
 import os
+from pathlib import Path
+from typing import Any, Type
 
-from path import Path
-import pytest
 import cli_ui as ui
+import pytest
 
 import tsrc
 import tsrc.cli.main
 
-# This is the type of the `tsrc.Error` class itself.
-# it makes sense if you see a class as a callable
-# that returns instances of itself
-ErrorCtor = Callable[..., tsrc.Error]
-
 
 class CLI:
     def __init__(self) -> None:
         self.workspace_path = Path(os.getcwd())
 
-    def run(self, *args: str,) -> None:
+    def run(self, *args: str) -> None:
         ui.info(">", ui.bold, "tsrc", *args)
         tsrc.cli.main.testable_main(args)
 
@@ -27,14 +27,12 @@ class CLI:
         ui.info(ui.red, " (expecting failure)")
         with pytest.raises(tsrc.Error) as e:
             tsrc.cli.main.testable_main(args)
-        return e.value  # type: ignore
+        return e.value
 
-    def run_and_fail_with(self, error: ErrorCtor, *args: str) -> tsrc.Error:
-        ui.info(">", ui.bold, "tsrc", *args, end="")
-        ui.info(ui.red, " (expecting failure)")
-        with pytest.raises(error) as e:
-            tsrc.cli.main.testable_main(args)
-        return e.value  # type: ignore
+    def run_and_fail_with(self, error: Type[tsrc.Error], *args: str) -> tsrc.Error:
+        actual_error = self.run_and_fail(*args)
+        assert isinstance(actual_error, error)
+        return actual_error
 
 
 @pytest.fixture
