@@ -1,10 +1,10 @@
 """ Implementation of the tsrc Workspace: a collection of git repositories
 """
 
+from pathlib import Path
 from typing import Iterable, List, Tuple
 
 import cli_ui as ui
-from path import Path
 import ruamel.yaml
 
 import tsrc
@@ -20,7 +20,7 @@ from .syncer import Syncer
 
 
 def copy_cfg_path_if_needed(root_path: Path) -> None:
-    """ Backward compatibility layer with tsrc < 1.0 """
+    """Backward compatibility layer with tsrc < 1.0"""
     old_path = root_path / ".tsrc/manifest.yml"
     new_path = root_path / ".tsrc/config.yml"
     if old_path.exists() and not new_path.exists():
@@ -50,7 +50,7 @@ class Workspace:
 
         # Note: at this point the repositories on which the user wishes to
         # execute an action is unknown. This list will be set after processing
-        # the command line arguments (like `--group` or `--all-cloned`)
+        # the command line arguments (like `--group` or `--all-cloned`).
         #
         # In particular, you _cannot assume_ that every repo in this list was
         # cloned - in other words, don't use `workspace.root_path / repo.dest`
@@ -107,7 +107,7 @@ class Workspace:
             syncer.display_bad_branches()
 
     def enumerate_repos(self) -> Iterable[Tuple[int, tsrc.Repo, Path]]:
-        """ Yield (index, repo, full_path) for all the repos """
+        """Yield (index, repo, full_path) for all the repos"""
         for i, repo in enumerate(self.repos):
             full_path = self.root_path / repo.dest
             yield (i, repo, full_path)
