@@ -1,12 +1,18 @@
+from pathlib import Path
 from typing import List, Optional
+
 import attr
-from path import Path
 import ruamel.yaml
 
 
 @attr.s
 class WorkspaceConfig:
-    """ Persistent configuration of the workspace """
+    """Persistent configuration of the workspace.
+
+    Stored in <workspace>/.tsrc/config.yml, and can be
+    edited by hand to use a different set of groups
+    for instance.
+    """
 
     manifest_url = attr.ib()  # type: str
     manifest_branch = attr.ib()  # type: str
@@ -29,7 +35,7 @@ class WorkspaceConfig:
         return cls(**parsed)
 
     def save_to_file(self, cfg_path: Path) -> None:
-        cfg_path.parent.makedirs_p()
+        cfg_path.parent.mkdir(parents=True, exist_ok=True)
         yaml = ruamel.yaml.YAML(typ="rt")
         yaml.register_class(Path)
         as_dict = attr.asdict(self)
